Crate luars

Crate luars 

Re-exports

pub use lua_value::LuaUserdata;
pub use lua_value::userdata_trait::LuaEnum;
pub use lua_value::userdata_trait::LuaMethodProvider;
pub use lua_value::userdata_trait::LuaRegistrable;
pub use lua_value::userdata_trait::LuaStaticMethodProvider;
pub use lua_value::userdata_trait::UdValue;
pub use lua_value::userdata_trait::UserDataTrait;
pub use lib_registry::LibraryRegistry;
pub use lua_value::RustCallback;
pub use lua_value::lua_convert::FromLua;
pub use lua_value::lua_convert::IntoLua;
pub use lua_value::Chunk;
pub use lua_value::LuaFunction;
pub use lua_value::LuaTable;
pub use lua_value::LuaValue;
pub use lua_vm::async_thread::AsyncFuture;
pub use lua_vm::async_thread::AsyncReturnValue;
pub use lua_vm::async_thread::AsyncThread;
pub use lua_vm::Instruction;
pub use lua_vm::LuaResult;
pub use lua_vm::LuaVM;
pub use lua_vm::OpCode;
pub use stdlib::Stdlib;
pub use gc::*;

Modules

compiler
gc
lib_registry
lua_value
lua_vm
stdlib

Macros

impl_simple_userdata
Implement UserDataTrait for types that only need type name and downcast support. These types use metatables for their Lua-visible API (e.g., IO file handles).
lib_module
Builder for creating library modules with functions and values

Attribute Macros

lua_methods
Attribute macro on impl blocks — exposes public methods to Lua.

Derive Macros

LuaUserData
Derive UserDataTrait for a struct, exposing public fields to Lua.